

# -------------------------------------------------------------------------
# DMvsVA PAPER 
# How do the three techniques perform in terms of choice attachment?
# -------------------------------------------------------------------------
#
# Author: EVANTHIA DIMARA
#
# -------------------------------------------------------------------------
# Symbols
# -------------------------------------------------------------------------
# PC : Parallel Coordinates
# SM : Scatterplot Matrix
# TV : Tabular Visualization
# -------------------------------------------------------------------------

#rm(list = ls()) # clean up R's memory
digits  <- 2 # number of digits to show after the decimal point.

source("functions.R")

afterDM_data <- read.csv("results/VAandDSS - Post-response (Responses) - Form Responses 1_p21.csv") 
afterDM_attachment_data <- subset(afterDM_data, select = c("Participant.ID", "attachment", "technique"))
afterDM_attachment_data[,"attachment"] <-10 - afterDM_attachment_data[,"attachment"] #  taking (10 - response) for consistency: low is bad, high is good.]
#afterDM_attachment_data[,"attachment"] <-(afterDM_attachment_data[,"attachment"])/10
afterDM_attachment_data_PC <- subset(afterDM_attachment_data, technique=="PC")
afterDM_attachment_data_SM <- subset(afterDM_attachment_data, technique=="SM")
afterDM_attachment_data_TV <- subset(afterDM_attachment_data, technique=="TV")

#afterDM_attachment_data <- cbind(afterDM_data[,"Participant ID"], afterDM_data[,"attachment"]/10)

attachmentDM_diff_PC_SM_CI  <- meanCI(afterDM_attachment_data_PC[,"attachment"] - afterDM_attachment_data_SM[,"attachment"]) 
attachmentDM_diff_PC_TV_CI  <- meanCI(afterDM_attachment_data_PC[,"attachment"] - afterDM_attachment_data_TV[,"attachment"]) 
attachmentDM_diff_SM_TV_CI  <- meanCI(afterDM_attachment_data_SM[,"attachment"] - afterDM_attachment_data_TV[,"attachment"]) 

attachmentDM_PC_CI  <- meanCI(afterDM_attachment_data_PC[,"attachment"]) 
attachmentDM_SM_CI  <- meanCI(afterDM_attachment_data_SM[,"attachment"]) 
attachmentDM_TV_CI  <- meanCI( afterDM_attachment_data_TV[,"attachment"]) 

# Ploting all CI
results <- data.frame(label = "DM PC attachment" , point = attachmentDM_PC_CI[1], ci.lower = attachmentDM_PC_CI[2], ci.upper = attachmentDM_PC_CI[3], type='Other') 
results <- rbind(results, data.frame(label = "DM SM attachment" , point = attachmentDM_SM_CI[1], ci.lower = attachmentDM_SM_CI[2], ci.upper = attachmentDM_SM_CI[3], type='Other'))  
results <- rbind(results, data.frame(label = "DM TV attachment" , point = attachmentDM_TV_CI[1], ci.lower = attachmentDM_TV_CI[2], ci.upper = attachmentDM_TV_CI[3], type='Other'))  
results2 <-data.frame(label = "DM PC-SM attachment Difference " , point = attachmentDM_diff_PC_SM_CI[1], ci.lower = attachmentDM_diff_PC_SM_CI[2], ci.upper = attachmentDM_diff_PC_SM_CI[3], type='Other')
results2 <- rbind(results2, data.frame(label = "DM PC-TV attachment Difference " , point = attachmentDM_diff_PC_TV_CI[1], ci.lower = attachmentDM_diff_PC_TV_CI[2], ci.upper = attachmentDM_diff_PC_TV_CI[3], type='Other'))  
results2 <- rbind(results2, data.frame(label = "DM SM-TV attachment Difference " , point = attachmentDM_diff_SM_TV_CI[1], ci.lower = attachmentDM_diff_SM_TV_CI[2], ci.upper = attachmentDM_diff_SM_TV_CI[3], type='Other'))  

plot    <- plotAllCI_likertScale(results)
plot

plot    <- plotAllCI(results2, plotRange = c(-4, 4))
plot


# Printing exact values
attachmentDM_diff_PC_SM_CIform  <- format_ci( attachmentDM_diff_PC_SM_CI, digits, width = NA, FALSE)
attachmentDM_diff_PC_TV_CIform  <- format_ci( attachmentDM_diff_PC_TV_CI, digits, width = NA, FALSE)
attachmentDM_diff_SM_TV_CIform  <- format_ci( attachmentDM_diff_SM_TV_CI, digits, width = NA, FALSE)

attachmentDM_PC_CIform  <- format_ci( attachmentDM_PC_CI, digits, width = NA, FALSE)
attachmentDM_SM_CIform  <- format_ci( attachmentDM_SM_CI, digits, width = NA, FALSE)
attachmentDM_TV_CIform  <- format_ci( attachmentDM_TV_CI, digits, width = NA, FALSE)

cat("\n1.# How do the three techniques perform in terms of choice attachment?")
cat("\n2. DM attachment PC : ",attachmentDM_PC_CIform)
cat("\n2. DM attachment SM: " ,attachmentDM_SM_CIform)
cat("\n2. DM attachment TV: " ,attachmentDM_TV_CIform)
cat("\n2. DM attachment Difference PC-SM: ",attachmentDM_diff_PC_SM_CIform)
cat("\n2. DM attachment Difference PC-TV: ",attachmentDM_diff_PC_TV_CIform)
cat("\n2. DM attachment Difference SM-TV: ",attachmentDM_diff_SM_TV_CIform)

