# -------------------------------------------------------------------------
# DMvsVA PAPER 
# How do the three techniques perform in terms of accuracy (consistency with declared preferences) in DM task?
# -------------------------------------------------------------------------
#
# Author: EVANTHIA DIMARA
#
# -------------------------------------------------------------------------
# 

# Algorith used:
# -------------------------------------------------------------------------------------------------------------
# STEP 1: computing (unormalized) desirability score per package for preferences before the technique was used
# -------------------------------------------------------------------------------------------------------------
# For each participant
#   take preference1
#   For each package 
#     score1 = 0;
#     For each attribute
#       - take package's value X 
#       - normalize(X) **
#       - if (preference1---> small values) X = 1-X
#       - X*(attribute's importance)
#       - score1 += X
# 
#   normalize(X) : dividing by the maximum allowed value 
#   (100 for most attributes, something else for price). 
#   (don't normalize by min value to reflect the fact that prices are rather similar)
# -------------------------------------------------------------------------------------------------------------
#
# -------------------------------------------------------------------------------------------------------------
# STEP 2:  Normalizing desirability score: 
# -------------------------------------------------------------------------------------------------------------
# Compute min and max desirability
# For each participant
#   For each package 
#     - normalize score1 between 0 and 1 
# -------------------------------------------------------------------------------------------------------------
# Repeat STEP 1, 2 for for preferences after the technique was used (score2) 
# -------------------------------------------------------------------------------------------------------------
# STEP 3 : computing consistency per participant
# For each participant 
#   - compute maxScore1 and maxScore2
#   - find responseScore1 and responseScore2 
#   - diff1 =  maxScore1 - responseScore1
#   - diff2 =  maxScore2 - responseScore2
#   - discrepancy = min(diff1, diff2)
#   - consistency = 1 - discrepancy
# -------------------------------------------------------------------------------------------------------------
#
# Compute pairwise differences of the consistency score for each participant, 
# then average them across participants and use 95% bootstrap confidence intervals, 
# just like we do for the likeness measure, for example.
#


rm(list = ls()) # clean up R's memory
source("functions.R")

digits  <- 2 # number of digits to show after the decimal point.


# reading results and task data
participants      <- read.csv("results/TEST_ANALYSIS_participants.csv")   # from my server
dm_observations   <- read.csv("results/TEST_ANALYSIS_index_participant_to_task_dms.csv")   # from my server
dm_tasks          <- read.csv("tasks/holidays-dm-tasks.csv") # from my server
holiday20         <- read.csv("tasks/holidays-20.csv")  # Pierre's datasets
holiday21         <- read.csv("tasks/holidays-21.csv")  # Pierre's datasets
holiday22         <- read.csv("tasks/holidays-22.csv")  # Pierre's datasets
dm_preferences    <- read.csv("results/TEST_ANALYSIS_VAandDSS - Preferences (Responses) - Form Responses 1.csv") # Pierre's questionnaire

participants[c(2:2,4:7)] <- list(NULL)
dm_observations  <- merge(dm_observations,dm_tasks,by="taskid")
dm_preferences_rows <- nrow(dm_preferences)


# useful for iterations
attributes <- c("price", "hotel","archaeological","landscape","nightlife","security","sport","kids")
attributeDirections <- c("price.direction", "hotel.direction","archaeological.direction","landscape.direction","nightlife.direction","security.direction","sport.direction","kids.direction")
attr_direct <- data.frame(attributes, attributeDirections)
attr_direct_rows  <- nrow(attr_direct)
attributes_rows     <- nrow(attributes)



# Participant responses (match response with packageID). Result dframes: dm_observations20, dm_observations21,dm_observations22
holiday20$label <- tolower(holiday20$label)
holiday21$label <- tolower(holiday21$label)
holiday22$label <- tolower(holiday22$label)
dm_observations$response <- tolower(dm_observations$response)

dm_observations20 <- subset(dm_observations, taskid==1)
dm_observations21 <- subset(dm_observations, taskid==2)
dm_observations22 <- subset(dm_observations, taskid==3)

dm_observations20 <- merge(holiday20,dm_observations20,by.x=c("label"), by.y=c("response"))
dm_observations21 <- merge(holiday21,dm_observations21,by.x=c("label"), by.y=c("response"))
dm_observations22 <- merge(holiday22,dm_observations22,by.x=c("label"), by.y=c("response"))

attach(dm_observations20)
dm_observations20 <- dm_observations20[order(participantid),]
detach(dm_observations20)
dm_observations20[c(3:10,13:13,15:16, 18:19)] <- list(NULL)

attach(dm_observations21)
dm_observations21 <- dm_observations21[order(participantid),]
detach(dm_observations21)
dm_observations21[c(3:10,13:13,15:16, 18:19)] <- list(NULL)

attach(dm_observations22)
dm_observations22 <- dm_observations22[order(participantid),]
detach(dm_observations22)
dm_observations22[c(3:10,13:13,15:16, 18:19)] <- list(NULL)


# Create dataframes to assign scores per participant in each holiday package. Result: partic_packag20,partic_packag21,partic_packag22
partic_packag20 <-merge(participants,holiday20)
attach(partic_packag20)
partic_packag20 <- partic_packag20[order(id,packageId),]
detach(partic_packag20)
partic_packag20[,'scoreBEFORE'] <- 0 # score when preferences were collected BEFORE using the technique in holidays-20 dataset (task 1)
partic_packag20[,'scoreAFTER'] <- 0 # score when preferences were collected AFTER using the technique in holidays-20 dataset (task 1)
max20 <- apply(partic_packag20[,attributes], 2, FUN=max)

partic_packag21 <-merge(participants,holiday21)
attach(partic_packag21)
partic_packag21 <- partic_packag21[order(id,packageId),]
detach(partic_packag21)
partic_packag21[,'scoreBEFORE'] <- 0 # score when preferences were collected BEFORE using the technique in holidays-21 dataset (task 2)
partic_packag21[,'scoreAFTER'] <- 0  # score when preferences were collected AFTER using the technique in holidays-21 dataset (task 2)
max21 <- apply(partic_packag21[,attributes], 2, FUN=max)

partic_packag22 <-merge(participants,holiday22)
attach(partic_packag22)
partic_packag22 <- partic_packag22[order(id,packageId),]
detach(partic_packag22)
partic_packag22[,'scoreBEFORE'] <- 0 # score when preferences were collected BEFORE using the technique in holidays-22 dataset (task 3)
partic_packag22[,'scoreAFTER'] <- 0 # score when preferences were collected AFTER using the technique in holidays-22 dataset (task 3)
max22 <- apply(partic_packag22[,attributes], 2, FUN=max)


getPreference <- function(partic_packag, packrow, before) {
  for(i in 1:dm_preferences_rows){
    if(dm_preferences[i,"participantId"]==partic_packag[packrow,"id"] &&
         dm_preferences[i,"beforeTask"]==before){ return(i) &&
                                                    dm_preferences[i,"datasetName"]==partic_packag[packrow,"datasetName"]
    }
  }   
}

computeScores <- function(partic_packag, maxAttr)
{
  partic_packag_rows  <- nrow(partic_packag)
  for(i in 1:partic_packag_rows){
    partic_packag[i,attributes] = partic_packag[i,attributes]/maxAttr[attributes]
    prowBef = getPreference(partic_packag,i, before=TRUE)
    prowAft = getPreference(partic_packag,i, before=FALSE)  
    
    for(j in 1:attr_direct_rows){
      direction <-attr_direct[j,"attributeDirections"]
      attr <- attr_direct[j,"attributes"]
      
      attrValue <- partic_packag[i, paste(attr)]
      attrValueBef <- attrValue
      attrValueAft <- attrValue
      
      if(dm_preferences[prowBef , paste(direction)]=="Low"){
        attrValueBef = 1-attrValueBef
      }
      if(dm_preferences[prowAft , paste(direction)]=="Low"){
        attrValueAft = 1-attrValueAft
      }
      partic_packag[i,'scoreBEFORE'] = partic_packag[i,'scoreBEFORE'] + attrValueBef*dm_preferences[prowBef , paste(attr)]
      partic_packag[i,'scoreAFTER'] = partic_packag[i,'scoreAFTER'] + attrValueAft*dm_preferences[prowAft , paste(attr)]      
    } 
  }
  return(partic_packag)
}

partic_packag20 <- computeScores(partic_packag20,max20)
partic_packag21 <- computeScores(partic_packag21,max21)
partic_packag22 <- computeScores(partic_packag22,max22)


# normalize scores (when preferences we takedn before + after see the technique) according to minimum and maximum scores per participant
maxScorePerParticipant20BEFORE <- aggregate(scoreBEFORE ~ id, data = partic_packag20, FUN = max)
minScorePerParticipant20BEFORE <- aggregate(scoreBEFORE ~ id, data = partic_packag20, FUN = min)
maxScorePerParticipant21BEFORE <- aggregate(scoreBEFORE ~ id, data = partic_packag21, FUN = max)
minScorePerParticipant21BEFORE <- aggregate(scoreBEFORE ~ id, data = partic_packag21, FUN = min)
maxScorePerParticipant22BEFORE <- aggregate(scoreBEFORE ~ id, data = partic_packag22, FUN = max)
minScorePerParticipant22BEFORE <- aggregate(scoreBEFORE ~ id, data = partic_packag22, FUN = min)
maxScorePerParticipant20AFTER  <- aggregate(scoreAFTER  ~ id, data = partic_packag20, FUN = max)
minScorePerParticipant20AFTER  <- aggregate(scoreAFTER  ~ id, data = partic_packag20, FUN = min)
maxScorePerParticipant21AFTER  <- aggregate(scoreAFTER  ~ id, data = partic_packag21, FUN = max)
minScorePerParticipant21AFTER  <- aggregate(scoreAFTER  ~ id, data = partic_packag21, FUN = min)
maxScorePerParticipant22AFTER  <- aggregate(scoreAFTER  ~ id, data = partic_packag22, FUN = max)
minScorePerParticipant22AFTER  <- aggregate(scoreAFTER  ~ id, data = partic_packag22, FUN = min)

computeExtremaPerParticipant <- function (partic_packag,maxScorePerParticipantBEFORE,minScorePerParticipantBEFORE,maxScorePerParticipantAFTER,minScorePerParticipantAFTER )
{
  partic_packag_rows  <- nrow(partic_packag)
  for(i in 1:partic_packag_rows){
    partic_packag[i, 'maxScoreBEFORE'] = maxScorePerParticipantBEFORE[which(maxScorePerParticipantBEFORE$id == partic_packag[i, 'id']),"scoreBEFORE"]
    partic_packag[i, 'minScoreBEFORE'] = minScorePerParticipantBEFORE[which(minScorePerParticipantBEFORE$id == partic_packag[i, 'id']),"scoreBEFORE"]   
    partic_packag[i, 'maxScoreAFTER'] = maxScorePerParticipantAFTER[which(maxScorePerParticipantAFTER$id == partic_packag[i, 'id']),"scoreAFTER"]
    partic_packag[i, 'minScoreAFTER'] = minScorePerParticipantAFTER[which(minScorePerParticipantAFTER$id == partic_packag[i, 'id']),"scoreAFTER"]   
    
  }
  return (partic_packag)
}

partic_packag20 <- computeExtremaPerParticipant(partic_packag20, maxScorePerParticipant20BEFORE, minScorePerParticipant20BEFORE, maxScorePerParticipant20AFTER, minScorePerParticipant20AFTER)
partic_packag21 <- computeExtremaPerParticipant(partic_packag21, maxScorePerParticipant21BEFORE, minScorePerParticipant21BEFORE, maxScorePerParticipant21AFTER, minScorePerParticipant21AFTER)
partic_packag22 <- computeExtremaPerParticipant(partic_packag22, maxScorePerParticipant22BEFORE, minScorePerParticipant22BEFORE, maxScorePerParticipant22AFTER, minScorePerParticipant22AFTER)

partic_packag20[,"scoreBEFORE"] <- (partic_packag20[,"scoreBEFORE"]-partic_packag20[,"minScoreBEFORE"])/(partic_packag20[,"maxScoreBEFORE"]-partic_packag20[,"minScoreBEFORE"])
partic_packag20[,"scoreAFTER"]  <- (partic_packag20[,"scoreAFTER"]-partic_packag20[,"minScoreAFTER"])/(partic_packag20[,"maxScoreAFTER"]-partic_packag20[,"minScoreAFTER"])
partic_packag21[,"scoreBEFORE"] <- (partic_packag21[,"scoreBEFORE"]-partic_packag21[,"minScoreBEFORE"])/(partic_packag21[,"maxScoreBEFORE"]-partic_packag21[,"minScoreBEFORE"])
partic_packag21[,"scoreAFTER"]  <- (partic_packag21[,"scoreAFTER"]-partic_packag21[,"minScoreAFTER"])/(partic_packag21[,"maxScoreAFTER"]-partic_packag21[,"minScoreAFTER"])
partic_packag22[,"scoreBEFORE"] <- (partic_packag22[,"scoreBEFORE"]-partic_packag22[,"minScoreBEFORE"])/(partic_packag22[,"maxScoreBEFORE"]-partic_packag22[,"minScoreBEFORE"])
partic_packag22[,"scoreAFTER"]  <- (partic_packag22[,"scoreAFTER"]-partic_packag22[,"minScoreAFTER"])/(partic_packag22[,"maxScoreAFTER"]-partic_packag22[,"minScoreAFTER"])

# Computing consistency scores
participantScores20 = merge(x=dm_observations20,y=partic_packag20, by.x = c("participantid","packageId"), by.y=c("id","packageId"), all=FALSE)
participantScores21 = merge(x=dm_observations21,y=partic_packag21, by.x = c("participantid","packageId"), by.y=c("id","packageId"), all=FALSE)
participantScores22 = merge(x=dm_observations22,y=partic_packag22, by.x = c("participantid","packageId"), by.y=c("id","packageId"), all=FALSE)

participantScores = rbind(participantScores20, participantScores21,participantScores22)
participantScores$diff1 <- 1-participantScores$scoreBEFORE
participantScores$diff2 <- 1-participantScores$scoreAFTER
participantScores <- transform(participantScores, min = pmin(diff1, diff2))
participantScores$consistency <- 1- participantScores$min

# Computing and ploting consistency CI per technique 
participantScores_PC <- subset(participantScores, technique=="PC")
participantScores_SM <- subset(participantScores, technique=="SM")
participantScores_TV <- subset(participantScores, technique=="TV")

consistencyDM_PC_CI  <- meanCI(participantScores_PC[,"consistency"]) 
consistencyDM_SM_CI  <- meanCI(participantScores_SM[,"consistency"]) 
consistencyDM_TV_CI  <- meanCI(participantScores_TV[,"consistency"]) 

#consistencyDM_diff_PC_SM_CI  <- meanCI(participantScores_PC[,"consistency"] - participantScores_SM[,"consistency"]) 
#consistencyDM_diff_PC_TV_CI  <- meanCI(participantScores_PC[,"consistency"] - participantScores_TV[,"consistency"]) 
#consistencyDM_diff_SM_TV_CI  <- meanCI(participantScores_SM[,"consistency"] - participantScores_TV[,"consistency"]) 

# Ploting all CI
results <- data.frame(label = "DM PC consistency" , point =consistencyDM_PC_CI[1], ci.lower = consistencyDM_PC_CI[2], ci.upper = consistencyDM_PC_CI[3], type='Other') 
results <- rbind(results, data.frame(label = "DM SM consistency" , point = consistencyDM_SM_CI[1], ci.lower = consistencyDM_SM_CI[2], ci.upper = consistencyDM_SM_CI[3], type='Other'))  
results <- rbind(results, data.frame(label = "DM TV consistency" , point = consistencyDM_TV_CI[1], ci.lower = consistencyDM_TV_CI[2], ci.upper = consistencyDM_TV_CI[3], type='Other'))  
#results <- rbind(results, data.frame(label = "DM PC-SM consistency Difference " , point = consistencyDM_diff_PC_SM_CI[1], ci.lower = consistencyDM_diff_PC_SM_CI[2], ci.upper = consistencyDM_diff_PC_SM_CI[3], type='Other')) 
#results <- rbind(results, data.frame(label = "DM PC-TV consistency Difference " , point = consistencyDM_diff_PC_TV_CI[1], ci.lower = consistencyDM_diff_PC_TV_CI[2], ci.upper = consistencyDM_diff_PC_TV_CI[3], type='Other'))  
#results <- rbind(results, data.frame(label = "DM SM-TV consistency Difference " , point = consistencyDM_diff_SM_TV_CI[1], ci.lower = consistencyDM_diff_SM_TV_CI[2], ci.upper = consistencyDM_diff_SM_TV_CI[3], type='Other'))  

plot    <- plotAllCI_TEST(results)
plot

# Printing exact values
#consistencyDM_diff_PC_SM_CIform  <- format_ci( consistencyDM_diff_PC_SM_CI, digits, width = NA, FALSE)
#consistencyDM_diff_PC_TV_CIform  <- format_ci( consistencyDM_diff_PC_TV_CI, digits, width = NA, FALSE)
#consistencyDM_diff_SM_TV_CIform  <- format_ci( consistencyDM_diff_SM_TV_CI, digits, width = NA, FALSE)

consistencyDM_PC_CIform  <- format_ci( consistencyDM_PC_CI, digits, width = NA, FALSE)
consistencyDM_SM_CIform  <- format_ci( consistencyDM_SM_CI, digits, width = NA, FALSE)
consistencyDM_TV_CIform  <- format_ci( consistencyDM_TV_CI, digits, width = NA, FALSE)

cat("\n1.# How do the three techniques perform in terms of choice consistency?")
cat("\n2. DM consistency PC : ",consistencyDM_PC_CIform)
cat("\n2. DM consistency SM: " ,consistencyDM_SM_CIform)
cat("\n2. DM consistency TV: " ,consistencyDM_TV_CIform)
#cat("\n2. DM consistency Difference PC-SM: ",consistencyDM_diff_PC_SM_CIform)
#cat("\n2. DM consistency Difference PC-TV: ",consistencyDM_diff_PC_TV_CIform)
#cat("\n2. DM consistency Difference SM-TV: ",consistencyDM_diff_SM_TV_CIform)



