

# -------------------------------------------------------------------------
# DMvsVA PAPER 
# How do the three techniques perform in subjective decision making measures?
# -------------------------------------------------------------------------
#
# Author: EVANTHIA DIMARA
#
# -------------------------------------------------------------------------
# Symbols
# -------------------------------------------------------------------------
# PC : Parallel Coordinates
# SM : Scatterplot Matrix
# TV : Tabular Visualization
# -------------------------------------------------------------------------

rm(list = ls()) # clean up R's memory
digits  <- 2 # number of digits to show after the decimal point.

source("functions.R")

afterDM_data <- read.csv("results/VAandDSS - Post-response (Responses) - Form Responses 1_p19.csv") 

afterDM_subjective_data <- subset(afterDM_data, select = c("Participant.ID", "satisfaction","easiness","confidence","attachment", "technique"))
afterDM_subjective_data$mean <- rowMeans(afterDM_subjective_data[,2:5])
afterDM_subjective_data[,"mean"] <-afterDM_subjective_data[,"mean"]/10

afterDM_subjective_data_PC <- subset(afterDM_subjective_data, technique=="PC")
afterDM_subjective_data_SM <- subset(afterDM_subjective_data, technique=="SM")
afterDM_subjective_data_TV <- subset(afterDM_subjective_data, technique=="TV")

afterDM_subjective_diff_PC_SM_CI  <- meanCI(afterDM_subjective_data_PC[,"mean"] - afterDM_subjective_data_SM[,"mean"]) 
afterDM_subjective_diff_PC_TV_CI  <- meanCI(afterDM_subjective_data_PC[,"mean"] - afterDM_subjective_data_TV[,"mean"]) 
afterDM_subjective_diff_SM_TV_CI  <- meanCI(afterDM_subjective_data_SM[,"mean"] - afterDM_subjective_data_TV[,"mean"]) 

afterDM_subjective_PC_CI  <- meanCI(afterDM_subjective_data_PC[,"mean"]) 
afterDM_subjective_SM_CI  <- meanCI(afterDM_subjective_data_SM[,"mean"]) 
afterDM_subjective_TV_CI  <- meanCI(afterDM_subjective_data_TV[,"mean"]) 

# Ploting all CI
results <- data.frame(label = "DM PC subjective rating" , point = afterDM_subjective_PC_CI[1], ci.lower = afterDM_subjective_PC_CI[2], ci.upper = afterDM_subjective_PC_CI[3], type='Other') 
results <- rbind(results, data.frame(label = "DM SM subjective rating" , point = afterDM_subjective_SM_CI[1], ci.lower = afterDM_subjective_SM_CI[2], ci.upper = afterDM_subjective_SM_CI[3], type='Other'))  
results <- rbind(results, data.frame(label = "DM TV subjective rating" , point = afterDM_subjective_TV_CI[1], ci.lower = afterDM_subjective_TV_CI[2], ci.upper = afterDM_subjective_TV_CI[3], type='Other'))  
results <- rbind(results, data.frame(label = "DM PC-SM subjective rating Difference " , point = afterDM_subjective_diff_PC_SM_CI[1], ci.lower = afterDM_subjective_diff_PC_SM_CI[2], ci.upper = afterDM_subjective_diff_PC_SM_CI[3], type='Other')) 
results <- rbind(results, data.frame(label = "DM PC-TV subjective rating Difference " , point = afterDM_subjective_diff_PC_TV_CI[1], ci.lower = afterDM_subjective_diff_PC_TV_CI[2], ci.upper = afterDM_subjective_diff_PC_TV_CI[3], type='Other'))  
results <- rbind(results, data.frame(label = "DM SM-TV subjective rating Difference " , point = afterDM_subjective_diff_SM_TV_CI[1], ci.lower = afterDM_subjective_diff_SM_TV_CI[2], ci.upper = afterDM_subjective_diff_SM_TV_CI[3], type='Other'))  

plot    <- plotAllCI(results)
print(plot)

# Printing exact values
afterDM_subjective_diff_PC_SM_CIform  <- format_ci( afterDM_subjective_diff_PC_SM_CI, digits, width = NA, FALSE)
afterDM_subjective_diff_PC_TV_CIform  <- format_ci( afterDM_subjective_diff_PC_TV_CI, digits, width = NA, FALSE)
afterDM_subjective_diff_SM_TV_CIform  <- format_ci( afterDM_subjective_diff_SM_TV_CI, digits, width = NA, FALSE)

afterDM_subjective_PC_CIform  <- format_ci( afterDM_subjective_PC_CI, digits, width = NA, FALSE)
afterDM_subjective_SM_CIform  <- format_ci( afterDM_subjective_SM_CI, digits, width = NA, FALSE)
afterDM_subjective_TV_CIform  <- format_ci( afterDM_subjective_TV_CI, digits, width = NA, FALSE)

cat("\n1.# How do the three techniques perform in subjective decision making measures?")
cat("\n2. DM subjective rating  PC : ",afterDM_subjective_PC_CIform)
cat("\n2. DM subjective rating SM: " ,afterDM_subjective_SM_CIform)
cat("\n2. DM subjective rating TV: " ,afterDM_subjective_TV_CIform)
cat("\n2. DM subjective rating Difference PC-SM: ",afterDM_subjective_diff_PC_SM_CIform)
cat("\n2. DM subjective rating Difference PC-TV: ",afterDM_subjective_diff_PC_TV_CIform)
cat("\n2. DM subjective rating Difference SM-TV: ",afterDM_subjective_diff_SM_TV_CIform)






