# -------------------------------------------------------------------------
# DMvsVA PAPER 
# Did people change their VA preference in DM when using technique X?
# -------------------------------------------------------------------------
#
#

rm(list = ls()) # clean up R's memory
digits  <- 2 # number of digits to show after the decimal point.

source("functions.R")

afterVA_data <- read.csv("results/VAandDSS - After VA (Responses) - Form Responses 1_p21.csv") 
afterVA_data[,"Parallel.coordinates"] <-afterVA_data[,"Parallel.coordinates"]
afterVA_data[,"Scatterplot.matrix"] <-afterVA_data[,"Scatterplot.matrix"]
afterVA_data[,"Tabular.visualization"] <-afterVA_data[,"Tabular.visualization"]

afterDM_data <- read.csv("results/VAandDSS - Final (Responses) - Form Responses 1_p21.csv") 
afterDM_data[,"Parallel.coordinates"] <-afterDM_data[,"Parallel.coordinates"]
afterDM_data[,"Scatterplot.matrix"] <-afterDM_data[,"Scatterplot.matrix"]
afterDM_data[,"Tabular.visualization"] <-afterDM_data[,"Tabular.visualization"]

# ABSOLUTE DIFFERENCE
absdiffPref_PC<- abs(afterDM_data[,"Parallel.coordinates"] - afterVA_data[,"Parallel.coordinates"])
absdiffPref_SM<- abs(afterDM_data[,"Scatterplot.matrix"] - afterVA_data[,"Scatterplot.matrix"])
absdiffPref_TV<- abs(afterDM_data[,"Tabular.visualization"] - afterVA_data[,"Tabular.visualization"])

# DIFFERENCE
diffPref_PC<- (afterDM_data[,"Parallel.coordinates"] - afterVA_data[,"Parallel.coordinates"])
diffPref_SM<- (afterDM_data[,"Scatterplot.matrix"] - afterVA_data[,"Scatterplot.matrix"])
diffPref_TV<- (afterDM_data[,"Tabular.visualization"] - afterVA_data[,"Tabular.visualization"])

absdiffDMminusVA <-  data.frame("diffPref_PC"= absdiffPref_PC, "diffPref_SM"= absdiffPref_SM,"diffPref_TV"= absdiffPref_TV)
diffDMminusVA <-  data.frame("diffPref_PC"= diffPref_PC, "diffPref_SM"= diffPref_SM,"diffPref_TV"= diffPref_TV)

plotHistograms <- function(pc, sm, tv, xlim, ymax, breaks) {
  par(mfrow=c(3,1))
  hist(pc, col="black", border = "white", xlim = xlim, ylim = c(0, ymax), breaks = breaks)
  hist(sm, col="black", border = "white", xlim = xlim, ylim = c(0, ymax), breaks = breaks)
  hist(tv, col="black", border = "white", xlim = xlim, ylim = c(0, ymax), breaks = breaks)
}
#plotHistograms(diffPref_PC, diffPref_SM, diffPref_TV, c(-1,1), 15, 8)
plotHistograms(absdiffPref_PC, absdiffPref_SM, absdiffPref_TV, c(0,1), 15, 8)
plotHistograms(diffPref_PC, diffPref_SM, diffPref_TV, c(0,1), 15, 8)

absdiffPref_PC_CI   <- meanCI(absdiffPref_PC) 
absdiffPref_SM_CI   <- meanCI(absdiffPref_SM) 
absdiffPref_TV_CI   <- meanCI(absdiffPref_TV) 

diffPref_PC_CI   <- meanCI(diffPref_PC) 
diffPref_SM_CI   <- meanCI(diffPref_SM) 
diffPref_TV_CI   <- meanCI(diffPref_TV) 

results <- data.frame(label = "Absolute difference in preference  DM-VA for PC  " , point = absdiffPref_PC_CI[1], ci.lower = absdiffPref_PC_CI[2], ci.upper = absdiffPref_PC_CI[3], type='Other') 
results <- rbind(results, data.frame(label = "Difference in preference  DM-VA for PC  " , point = diffPref_PC_CI[1], ci.lower = diffPref_PC_CI[2], ci.upper = diffPref_PC_CI[3], type='Other'))
results <- rbind(results, data.frame(label = "Absolute difference in preference  DM-VA for SM  " , point = absdiffPref_SM_CI[1], ci.lower = absdiffPref_SM_CI[2], ci.upper = absdiffPref_SM_CI[3], type='Other'))  
results <- rbind(results, data.frame(label = "Difference in preference  DM-VA for SM  " , point = diffPref_SM_CI[1], ci.lower = diffPref_SM_CI[2], ci.upper = diffPref_SM_CI[3], type='Other'))  
results <- rbind(results, data.frame(label = "Absolute difference in preference  DM-VA for TV  " , point = absdiffPref_TV_CI[1], ci.lower = absdiffPref_TV_CI[2], ci.upper = absdiffPref_TV_CI[3], type='Other'))  
results <- rbind(results, data.frame(label = "Difference in preference  DM-VA for TV  " , point = diffPref_TV_CI[1], ci.lower = diffPref_TV_CI[2], ci.upper = diffPref_TV_CI[3], type='Other'))  


plot    <- plotAllCI(results, plotRange = c(-3.5, 3.5))
plot

diffPref_PC_CIform  <-format_ci( diffPref_PC_CI, digits, width = NA, FALSE)
diffPref_SM_CIform   <-format_ci( diffPref_SM_CI, digits, width = NA, FALSE)
diffPref_TV_CIform   <-format_ci( diffPref_TV_CI, digits, width = NA, FALSE)

absdiffPref_PC_CIform  <-format_ci( absdiffPref_PC_CI, digits, width = NA, FALSE)
absdiffPref_SM_CIform   <-format_ci( absdiffPref_SM_CI, digits, width = NA, FALSE)
absdiffPref_TV_CIform   <-format_ci( absdiffPref_TV_CI, digits, width = NA, FALSE)

cat("\n1. Did people change preference for technique when switching from analytic to decision making tasks?")
cat("\n2. PC difference : " ,diffPref_PC_CIform)
cat("\n3. SM difference : " ,diffPref_SM_CIform)
cat("\n4. TV difference : " ,diffPref_TV_CIform)
cat("\n5. PC absolute difference : " ,absdiffPref_PC_CIform)
cat("\n6. SM absolute difference : " ,absdiffPref_SM_CIform)
cat("\n7. TV absolute difference : " ,absdiffPref_TV_CIform)
