# -------------------------------------------------------------------------
# DMvsVA PAPER 
# How do the three techniques perform in terms of accuracy in Correlation task?
# -------------------------------------------------------------------------
#
# Author: EVANTHIA DIMARA
#
# -------------------------------------------------------------------------
# Symbols
# -------------------------------------------------------------------------
# Rtask : correlation task 
# PC : Parallel Coordinates
# SM : Scatterplot Matrix
# TV : Tabular Visualization
# -------------------------------------------------------------------------

#rm(list = ls()) # clean up R's memory

source("functions.R")

# How do the three techniques perform in terms of speed in value retrieval task?

Ctask_data  <- read.csv("results/index_participant_to_task_correlations_p21.csv") 
Ctask_tasks <- read.csv("tasks/grades-correlation-tasks.csv") 
colnames(Ctask_tasks)[1] <- "taskid"
Ctask_data  <- subset(Ctask_data, isTraining==0)
Ctask <- merge(Ctask_data,Ctask_tasks,by="taskid")
Ctask$response <- tolower(Ctask$response)
Ctask$attribute1Name <- tolower(substring(Ctask$attribute1Name,1,1))
Ctask$attribute2Name <- tolower(substring(Ctask$attribute2Name,1,1))
Ctask[c(2:2,4:4,6:7,9:10)] <- list(NULL)

Ctask_PC <- subset(Ctask, technique=="PC")
Ctask_SM <- subset(Ctask, technique=="SM")
Ctask_TV <- subset(Ctask, technique=="TV")

Ctask_PC$correct <- mapply(
  function(response, att1, att2) {grepl(att1, response) && grepl(att2, response)},
  Ctask_PC$response,
  Ctask_PC$attribute1Name,
  Ctask_PC$attribute2Name)
Ctask_PC$correct

Ctask_SM$correct <- mapply(
  function(response, att1, att2) {grepl(att1, response) && grepl(att2, response)},
  Ctask_SM$response,
  Ctask_SM$attribute1Name,
  Ctask_SM$attribute2Name)
Ctask_SM$correct

Ctask_TV$correct <- mapply(
  function(response, att1, att2) {grepl(att1, response) && grepl(att2, response)},
  Ctask_TV$response,
  Ctask_TV$attribute1Name,
  Ctask_TV$attribute2Name)
Ctask_TV$correct

Ctask_PC_scores <- ifelse(Ctask_PC$correct==TRUE,1,0)
Ctask_SM_scores <- ifelse(Ctask_SM$correct==TRUE,1,0)
Ctask_TV_scores <- ifelse(Ctask_TV$correct==TRUE,1,0)

Ctask_PC_mean_accuracy <- meanCI(Ctask_PC_scores)
Ctask_SM_mean_accuracy <- meanCI(Ctask_SM_scores)
Ctask_TV_mean_accuracy <- meanCI(Ctask_TV_scores)

# add manually limits of CI since all values are equal to 1 and cannot calculate confidence intervals
Ctask_SM_mean_accuracy[2] <- 1
Ctask_SM_mean_accuracy[3] <- 1
Ctask_TV_mean_accuracy[2] <- 1
Ctask_TV_mean_accuracy[3] <- 1

Ctask_diff_PCminusSM_accuracy  <- meanCI(Ctask_PC_scores - Ctask_SM_scores)
Ctask_diff_PCminusTV_accuracy  <- meanCI(Ctask_PC_scores - Ctask_TV_scores)
#Ctask_diff_SMminusTV_accuracy  <- meanCI(Ctask_SM_scores - Ctask_TV_scores)

# add manually limits diff SM - TV because confidence intervals error "estimated adjustment 'w' is infinite"
Ctask_diff_SMminusTV_accuracy <- c(0,0,0)

# Ploting all CI

results1 <- data.frame(label = "Correlation task: Mean accuracy PC" , point = Ctask_PC_mean_accuracy[1], ci.lower = Ctask_PC_mean_accuracy[2], ci.upper = Ctask_PC_mean_accuracy[3], type='Other' )
results1 <- rbind(results1, data.frame(label = "Correlation task: Mean accuracy SM" , point = Ctask_SM_mean_accuracy[1], ci.lower = Ctask_SM_mean_accuracy[2], ci.upper = Ctask_SM_mean_accuracy[3], type='Other'))  
results1 <- rbind(results1, data.frame(label = "Correlation task: Mean accuracy TV" , point = Ctask_TV_mean_accuracy[1], ci.lower = Ctask_TV_mean_accuracy[2], ci.upper = Ctask_TV_mean_accuracy[3], type='Other'))  

results2 <- data.frame(label = "Correlation task: PC-SM Accuracy Difference" , point = Ctask_diff_PCminusSM_accuracy[1], ci.lower = Ctask_diff_PCminusSM_accuracy[2], ci.upper = Ctask_diff_PCminusSM_accuracy[3], type='Other') 
results2 <- rbind(results2, data.frame(label = "Correlation task: PC-TV Accuracy Difference" , point = Ctask_diff_PCminusTV_accuracy[1], ci.lower = Ctask_diff_PCminusTV_accuracy[2], ci.upper = Ctask_diff_PCminusTV_accuracy[3], type='Other'))  
results2 <- rbind(results2, data.frame(label = "Correlation task: SM-TV Accuracy Difference" , point = Ctask_diff_SMminusTV_accuracy[1], ci.lower = Ctask_diff_SMminusTV_accuracy[2], ci.upper = Ctask_diff_SMminusTV_accuracy[3], type='Other'))  

plot    <- plotAllCI(results1, plotRange = c(0, 1))
plot

plot    <- plotAllCI(results2, plotRange = c(-1, 1))
plot


