# -------------------------------------------------------------------------
# DMvsVA PAPER 
# How do the three techniques perform in terms of speed in Correlation task?
# -------------------------------------------------------------------------
#
# Author: EVANTHIA DIMARA
#
# -------------------------------------------------------------------------
# Symbols
# -------------------------------------------------------------------------
# cTask : Correlation task 
# PC : Parallel Coordinates
# SM : Scatterplot Matrix
# TV : Tabular Visualization
# -------------------------------------------------------------------------

#rm(list = ls()) # clean up R's memory

source("functions.R")

digits  <- 2 # number of digits to show after the decimal point.

# How do the three techniques perform in terms of speed in Correlation task?
cTask_data <- read.csv("results/index_participant_to_task_correlations_p21.csv") 
cTask_data <- mergeStartEndColumnsToDuration(cTask_data)
cTask_data_PC <- averagePerParticipant(cTask_data, "PC")
cTask_data_SM <- averagePerParticipant(cTask_data, "SM")
cTask_data_TV <- averagePerParticipant(cTask_data,"TV")
vall <-rbind(cTask_data_PC, cTask_data_SM, cTask_data_TV)

Ctask_mean_PC  <- exp(meanCI.normal(cTask_data_PC))
Ctask_mean_SM  <- exp(meanCI.normal(cTask_data_SM))
Ctask_mean_TV  <- exp(meanCI.normal(cTask_data_TV)) 

Ctask_diff_PCminusSM  <- exp(meanCI.normal(cTask_data_PC - cTask_data_SM))
Ctask_diff_PCminusTV  <- exp(meanCI.normal(cTask_data_PC - cTask_data_TV))
Ctask_diff_SMminusTV  <- exp(meanCI.normal(cTask_data_SM - cTask_data_TV))


# Ploting all CI

results1 <- data.frame(label = "Correlation task: Mean time PC" , point = Ctask_mean_PC[1], ci.lower = Ctask_mean_PC[2], ci.upper = Ctask_mean_PC[3], type='Other' )
results1 <- rbind(results1, data.frame(label = "Correlation task: Mean time SM" , point = Ctask_mean_SM[1], ci.lower = Ctask_mean_SM[2], ci.upper = Ctask_mean_SM[3], type='Other'))  
results1 <- rbind(results1, data.frame(label = "Correlation task: Mean time TV" , point = Ctask_mean_TV[1], ci.lower = Ctask_mean_TV[2], ci.upper = Ctask_mean_TV[3], type='Other'))  

results2 <- data.frame(label = "Correlation task: Ratio time PC/SM" , point = Ctask_diff_PCminusSM[1], ci.lower = Ctask_diff_PCminusSM[2], ci.upper = Ctask_diff_PCminusSM[3], type='Other') 
results2 <- rbind(results2, data.frame(label = "Correlation task: Ratio time PC/TV" , point = Ctask_diff_PCminusTV[1], ci.lower = Ctask_diff_PCminusTV[2], ci.upper = Ctask_diff_PCminusTV[3], type='Other'))  
results2 <- rbind(results2, data.frame(label = "Correlation task: Ratio time SM/TV" , point = Ctask_diff_SMminusTV[1], ci.lower = Ctask_diff_SMminusTV[2], ci.upper = Ctask_diff_SMminusTV[3], type='Other'))  

plot    <- plotAllCI(results1, plotRange = c(0, 140))
plot

plot    <- plotAllCI(results2, plotRange = c(0, 12.3))
plot

# Printing exact values

Ctask_mean_PC_CIform  <- format_ci( Ctask_mean_PC, digits, width = NA, FALSE)
Ctask_mean_SM_CIform   <- format_ci( Ctask_mean_SM, digits, width = NA, FALSE)
Ctask_mean_TV_CIform   <-format_ci( Ctask_mean_TV, digits, width = NA, FALSE)

Ctask_diff_PCminusSM_CIform    <- format_ci( Ctask_diff_PCminusSM, digits, width = NA, FALSE)
Ctask_diff_PCminusTV_CIform    <- format_ci( Ctask_diff_PCminusTV, digits, width = NA, FALSE)
Ctask_diff_SMminusTV_CIform    <- format_ci( Ctask_diff_SMminusTV, digits, width = NA, FALSE)

cat("\n1. How do the three techniques perform in terms of speed in Correlation task?")
cat("\n2. VA: Time of Correlation task in PC : " ,Ctask_mean_PC_CIform)
cat("\n2. VA: Time of Correlation task in SM : " ,Ctask_mean_SM_CIform)
cat("\n2. VA: Time of Correlation task in TV : " ,Ctask_mean_TV_CIform)
cat("\n2. VA: Correlation Task Time Difference PC/SM: ",Ctask_diff_PCminusSM_CIform)
cat("\n2. VA: Correlation Task Time Difference PC/TV: ",Ctask_diff_PCminusTV_CIform)
cat("\n2. VA: Correlation Task Time Difference SM/TV: ",Ctask_diff_SMminusTV_CIform)
