# -------------------------------------------------------------------------
# DMvsVA PAPER 
# How do the three techniques perform in terms of accuracy in Range task?
# -------------------------------------------------------------------------
#
# Author: EVANTHIA DIMARA
#
# -------------------------------------------------------------------------
# Symbols
# -------------------------------------------------------------------------
# Rtask : range task 
# PC : Parallel Coordinates
# SM : Scatterplot Matrix
# TV : Tabular Visualization
# -------------------------------------------------------------------------

#rm(list = ls()) # clean up R's memory

source("functions.R")

# How do the three techniques perform in terms of speed in value retrieval task?
Rtask_data  <- read.csv("results/index_participant_to_task_ranges_p21.csv") 
Rtask_tasks <- read.csv("tasks/grades-range-tasks.csv") 
Rtask_data  <- subset(Rtask_data, isTraining== 0)
Rtask_data
Rtask_data[c(1:1,5:7)] <- list(NULL)
colnames(Rtask_tasks)[1] <- "taskid"
Rtask_data
Rtask <- merge(Rtask_data,Rtask_tasks,by="taskid")

Rtask_PC <- subset(Rtask, technique=="PC")
#Rtask_PC_scores <- ifelse(Rtask_PC$response==Rtask_PC$numberOfPoints,1,0)
Rtask_PC_scores <- 1 - abs(Rtask_PC$numberOfPoints - Rtask_PC$response)/4
Rtask_PC_scores

Rtask_SM <- subset(Rtask, technique=="SM")
#Rtask_SM_scores <- ifelse(Rtask_SM$response==Rtask_SM$numberOfPoints,1,0)
Rtask_SM_scores <- 1 - abs(Rtask_SM$numberOfPoints - Rtask_SM$response)/4
Rtask_SM_scores

Rtask_TV <- subset(Rtask, technique=="TV")
#Rtask_TV_scores <- ifelse(Rtask_TV$response==Rtask_TV$numberOfPoints,1,0)
Rtask_TV_scores <- 1 - abs(Rtask_TV$numberOfPoints - Rtask_TV$response)/4
Rtask_TV_scores

Rtask_PC_mean_accuracy <- meanCI(Rtask_PC_scores)
Rtask_SM_mean_accuracy <- meanCI(Rtask_SM_scores)
Rtask_TV_mean_accuracy <- meanCI(Rtask_TV_scores)

Rtask_diff_PCminusSM_accuracy  <- meanCI(Rtask_PC_scores - Rtask_SM_scores)
Rtask_diff_PCminusTV_accuracy  <- meanCI(Rtask_PC_scores - Rtask_TV_scores)
Rtask_diff_SMminusTV_accuracy  <- meanCI(Rtask_SM_scores - Rtask_TV_scores)


# Ploting all CI

results1 <- data.frame(label = "Range task: Mean accuracy PC" , point = Rtask_PC_mean_accuracy[1], ci.lower = Rtask_PC_mean_accuracy[2], ci.upper = Rtask_PC_mean_accuracy[3], type='Other' )
results1 <- rbind(results1, data.frame(label = "Range task: Mean accuracy SM" , point = Rtask_SM_mean_accuracy[1], ci.lower = Rtask_SM_mean_accuracy[2], ci.upper = Rtask_SM_mean_accuracy[3], type='Other'))  
results1 <- rbind(results1, data.frame(label = "Range task: Mean accuracy TV" , point = Rtask_TV_mean_accuracy[1], ci.lower = Rtask_TV_mean_accuracy[2], ci.upper = Rtask_TV_mean_accuracy[3], type='Other'))  

results2 <- data.frame(label = "Range task: PC-SM Accuracy Difference" , point = Rtask_diff_PCminusSM_accuracy[1], ci.lower = Rtask_diff_PCminusSM_accuracy[2], ci.upper = Rtask_diff_PCminusSM_accuracy[3], type='Other') 
results2 <- rbind(results2, data.frame(label = "Range task: PC-TV Accuracy Difference" , point = Rtask_diff_PCminusTV_accuracy[1], ci.lower = Rtask_diff_PCminusTV_accuracy[2], ci.upper = Rtask_diff_PCminusTV_accuracy[3], type='Other'))  
results2 <- rbind(results2, data.frame(label = "Range task: SM-TV Accuracy Difference" , point = Rtask_diff_SMminusTV_accuracy[1], ci.lower = Rtask_diff_SMminusTV_accuracy[2], ci.upper = Rtask_diff_SMminusTV_accuracy[3], type='Other'))  

plot    <- plotAllCI(results1, plotRange = c(0, 1))
plot

plot    <- plotAllCI(results2, plotRange = c(-1, 1))
plot
