# -------------------------------------------------------------------------
# DMvsVA PAPER 
# How do the three techniques perform in terms of speed in Range task?
# -------------------------------------------------------------------------
#
# Author: EVANTHIA DIMARA
#
# -------------------------------------------------------------------------
# Symbols
# -------------------------------------------------------------------------
# Rtask : Range task 
# PC : Parallel Coordinates
# SM : Scatterplot Matrix
# TV : Tabular Visualization
# -------------------------------------------------------------------------

#rm(list = ls()) # clean up R's memory

source("functions.R")

digits  <- 2 # number of digits to show after the decimal point.

# How do the three techniques perform in terms of speed in Range task?
Rtask_data <- read.csv("results/index_participant_to_task_ranges_p21.csv") 
Rtask_data <- mergeStartEndColumnsToDuration(Rtask_data)
Rtask_data_PC <- averagePerParticipant(Rtask_data, "PC")
Rtask_data_SM <- averagePerParticipant(Rtask_data, "SM")
Rtask_data_TV <- averagePerParticipant(Rtask_data,"TV")
vall <-rbind(Rtask_data_PC, Rtask_data_SM, Rtask_data_TV)

Rtask_mean_PC  <- exp(meanCI.normal(Rtask_data_PC))
Rtask_mean_SM  <- exp(meanCI.normal(Rtask_data_SM))
Rtask_mean_TV  <- exp(meanCI.normal(Rtask_data_TV)) 

Rtask_diff_PCminusSM  <- exp(meanCI.normal(Rtask_data_PC - Rtask_data_SM))
Rtask_diff_PCminusTV  <- exp(meanCI.normal(Rtask_data_PC - Rtask_data_TV))
Rtask_diff_SMminusTV  <- exp(meanCI.normal(Rtask_data_SM - Rtask_data_TV))


# Ploting all CI

results1 <- data.frame(label = "Range task: Mean time PC" , point = Rtask_mean_PC[1], ci.lower = Rtask_mean_PC[2], ci.upper = Rtask_mean_PC[3], type='Other' )
results1 <- rbind(results1, data.frame(label = "Range task: Mean time SM" , point = Rtask_mean_SM[1], ci.lower = Rtask_mean_SM[2], ci.upper = Rtask_mean_SM[3], type='Other'))  
results1 <- rbind(results1, data.frame(label = "Range task: Mean time TV" , point = Rtask_mean_TV[1], ci.lower = Rtask_mean_TV[2], ci.upper = Rtask_mean_TV[3], type='Other'))  

results2 <- data.frame(label = "Range task: Ratio time PC/SM" , point = Rtask_diff_PCminusSM[1], ci.lower = Rtask_diff_PCminusSM[2], ci.upper = Rtask_diff_PCminusSM[3], type='Other') 
results2 <- rbind(results2, data.frame(label = "Range task: Ratio time PC/TV" , point = Rtask_diff_PCminusTV[1], ci.lower = Rtask_diff_PCminusTV[2], ci.upper = Rtask_diff_PCminusTV[3], type='Other'))  
results2 <- rbind(results2, data.frame(label = "Range task: Ratio time SM/TV" , point = Rtask_diff_SMminusTV[1], ci.lower = Rtask_diff_SMminusTV[2], ci.upper = Rtask_diff_SMminusTV[3], type='Other'))  

plot    <- plotAllCI(results1, plotRange = c(0, 65))
plot

plot    <- plotAllCI(results2, plotRange = c(0, 2.2))
plot

# Printing exact values

Rtask_mean_PC_CIform  <- format_ci( Rtask_mean_PC, digits, width = NA, FALSE)
Rtask_mean_SM_CIform   <- format_ci( Rtask_mean_SM, digits, width = NA, FALSE)
Rtask_mean_TV_CIform   <-format_ci( Rtask_mean_TV, digits, width = NA, FALSE)

Rtask_diff_PCminusSM_CIform    <- format_ci( Rtask_diff_PCminusSM, digits, width = NA, FALSE)
Rtask_diff_PCminusTV_CIform    <- format_ci( Rtask_diff_PCminusTV, digits, width = NA, FALSE)
Rtask_diff_SMminusTV_CIform    <- format_ci( Rtask_diff_SMminusTV, digits, width = NA, FALSE)

cat("\n1. How do the three techniques perform in terms of speed in Range task?")
cat("\n2. VA: Time of Range task in PC : " ,Rtask_mean_PC_CIform)
cat("\n2. VA: Time of Range task in SM : " ,Rtask_mean_SM_CIform)
cat("\n2. VA: Time of Range task in TV : " ,Rtask_mean_TV_CIform)
cat("\n2. VA: Range Task Time Difference PC/SM: ",Rtask_diff_PCminusSM_CIform)
cat("\n2. VA: Range Task Time Difference PC/TV: ",Rtask_diff_PCminusTV_CIform)
cat("\n2. VA: Range Task Time Difference SM/TV: ",Rtask_diff_PCminusTV_CIform)
