# -------------------------------------------------------------------------
# DMvsVA PAPER 
# How do the three techniques perform in terms of accuracy in Value retrieval task?
# -------------------------------------------------------------------------
#
# Author: EVANTHIA DIMARA
#
# -------------------------------------------------------------------------
# Symbols
# -------------------------------------------------------------------------
# Vtask : value revtieval task 
# PC : Parallel Coordinates
# SM : Scatterplot Matrix
# TV : Tabular Visualization
# -------------------------------------------------------------------------

#rm(list = ls()) # clean up R's memory

source("functions.R")

# How do the three techniques perform in terms of speed in value retrieval task?
Vtask_data  <- read.csv("results/index_participant_to_task_value_retrievals_p21.csv") 
Vtask_tasks <- read.csv("tasks/grades-retrieval-tasks.csv") 
Vtask_data  <- subset(Vtask_data, isTraining== 0)
Vtask_data[c(1:1,4:4,6:7)] <- list(NULL)
colnames(Vtask_tasks)[1] <- "taskid"
Vtask <- merge(Vtask_data,Vtask_tasks,by="taskid")

Vtask_PC <- subset(Vtask, technique=="PC")
Vtask_SM <- subset(Vtask, technique=="SM")
Vtask_TV <- subset(Vtask, technique=="TV")

Vtask_PC_scores <- ifelse(Vtask_PC$response==Vtask_PC$attribute2Value,1,0)
Vtask_SM_scores <- ifelse(Vtask_SM$response==Vtask_SM$attribute2Value,1,0)
Vtask_TV_scores <- ifelse(Vtask_TV$response==Vtask_TV$attribute2Value,1,0)

Vtask_PC_mean_accuracy <- meanCI(Vtask_PC_scores)
Vtask_SM_mean_accuracy <- meanCI(Vtask_SM_scores)
Vtask_TV_mean_accuracy <- meanCI(Vtask_TV_scores)

# add manually limits of CI since I get "NA"
Vtask_PC_mean_accuracy[2] <- 1
Vtask_PC_mean_accuracy[3] <- 1

Vtask_diff_PCminusSM_accuracy  <- meanCI(Vtask_PC_scores - Vtask_SM_scores)
Vtask_diff_PCminusTV_accuracy  <- meanCI(Vtask_PC_scores - Vtask_TV_scores)
Vtask_diff_SMminusTV_accuracy  <- meanCI(Vtask_SM_scores - Vtask_TV_scores)

# Ploting all CI

results1 <- data.frame(label = "Value task: Mean accuracy PC" , point = Vtask_PC_mean_accuracy[1], ci.lower = Vtask_PC_mean_accuracy[2], ci.upper = Vtask_PC_mean_accuracy[3], type='Other' )
results1 <- rbind(results1, data.frame(label = "Value task: Mean accuracy SM" , point = Vtask_SM_mean_accuracy[1], ci.lower = Vtask_SM_mean_accuracy[2], ci.upper = Vtask_SM_mean_accuracy[3], type='Other'))  
results1 <- rbind(results1, data.frame(label = "Value task: Mean accuracy TV" , point = Vtask_TV_mean_accuracy[1], ci.lower = Vtask_TV_mean_accuracy[2], ci.upper = Vtask_TV_mean_accuracy[3], type='Other'))  

results2 <- data.frame(label = "Value task: PC-SM Accuracy Difference" , point = Vtask_diff_PCminusSM_accuracy[1], ci.lower = Vtask_diff_PCminusSM_accuracy[2], ci.upper = Vtask_diff_PCminusSM_accuracy[3], type='Other') 
results2 <- rbind(results2, data.frame(label = "Value task: PC-TV Accuracy Difference" , point = Vtask_diff_PCminusTV_accuracy[1], ci.lower = Vtask_diff_PCminusTV_accuracy[2], ci.upper = Vtask_diff_PCminusTV_accuracy[3], type='Other'))  
results2 <- rbind(results2, data.frame(label = "Value task: SM-TV Accuracy Difference" , point = Vtask_diff_SMminusTV_accuracy[1], ci.lower = Vtask_diff_SMminusTV_accuracy[2], ci.upper = Vtask_diff_SMminusTV_accuracy[3], type='Other'))  

plot    <- plotAllCI(results1, plotRange = c(0, 1))
plot

plot    <- plotAllCI(results2, plotRange = c(-1, 1))
plot


