# -------------------------------------------------------------------------
# DMvsVA PAPER 
# How do the three techniques perform in terms of speed in Value retrieval task?
# -------------------------------------------------------------------------
#
# Author: EVANTHIA DIMARA
#
# -------------------------------------------------------------------------
# Symbols
# -------------------------------------------------------------------------
# Vtask : value revtieval task 
# PC : Parallel Coordinates
# SM : Scatterplot Matrix
# TV : Tabular Visualization
# -------------------------------------------------------------------------

#rm(list = ls()) # clean up R's memory

source("functions.R")

digits  <- 2 # number of digits to show after the decimal point.

# How do the three techniques perform in terms of speed in value retrieval task?
Vtask_data <- read.csv("results/index_participant_to_task_value_retrievals_p21.csv") 
Vtask_data <- mergeStartEndColumnsToDuration(Vtask_data)
Vtask_data_PC <- averagePerParticipant(Vtask_data, "PC")
Vtask_data_SM <- averagePerParticipant(Vtask_data, "SM")
Vtask_data_TV <- averagePerParticipant(Vtask_data,"TV")
vall <-rbind(Vtask_data_PC, Vtask_data_SM, Vtask_data_TV)

Vtask_mean_PC  <- exp(meanCI.normal(Vtask_data_PC))
Vtask_mean_SM  <- exp(meanCI.normal(Vtask_data_SM))
Vtask_mean_TV  <- exp(meanCI.normal(Vtask_data_TV)) 

Vtask_diff_PCminusSM  <- exp(meanCI.normal(Vtask_data_PC - Vtask_data_SM))
Vtask_diff_PCminusTV  <- exp(meanCI.normal(Vtask_data_PC - Vtask_data_TV))
Vtask_diff_SMminusTV  <- exp(meanCI.normal(Vtask_data_SM - Vtask_data_TV))


# Ploting all CI

results1 <- data.frame(label = "Value task: Mean time PC" , point = Vtask_mean_PC[1], ci.lower = Vtask_mean_PC[2], ci.upper = Vtask_mean_PC[3], type='Other' )
results1 <- rbind(results1, data.frame(label = "Value task: Mean time SM" , point = Vtask_mean_SM[1], ci.lower = Vtask_mean_SM[2], ci.upper = Vtask_mean_SM[3], type='Other'))  
results1 <- rbind(results1, data.frame(label = "Value task: Mean time TV" , point = Vtask_mean_TV[1], ci.lower = Vtask_mean_TV[2], ci.upper = Vtask_mean_TV[3], type='Other'))  

results2 <- data.frame(label = "Value task: Ratio time PC/SM" , point = Vtask_diff_PCminusSM[1], ci.lower = Vtask_diff_PCminusSM[2], ci.upper = Vtask_diff_PCminusSM[3], type='Other') 
results2 <- rbind(results2, data.frame(label = "Value task: Ratio time PC/TV" , point = Vtask_diff_PCminusTV[1], ci.lower = Vtask_diff_PCminusTV[2], ci.upper = Vtask_diff_PCminusTV[3], type='Other'))  
results2 <- rbind(results2, data.frame(label = "Value task: Ratio time SM/TV" , point = Vtask_diff_SMminusTV[1], ci.lower = Vtask_diff_SMminusTV[2], ci.upper = Vtask_diff_SMminusTV[3], type='Other'))  

plot    <- plotAllCI(results1, plotRange = c(0, 40))
plot

plot    <- plotAllCI(results2, plotRange = c(0.2, 2.2))
plot

# Printing exact values

Vtask_mean_PC_CIform  <- format_ci( Vtask_mean_PC, digits, width = NA, FALSE)
Vtask_mean_SM_CIform   <- format_ci( Vtask_mean_SM, digits, width = NA, FALSE)
Vtask_mean_TV_CIform   <-format_ci( Vtask_mean_TV, digits, width = NA, FALSE)

Vtask_diff_PCminusSM_CIform    <- format_ci( Vtask_diff_PCminusSM, digits, width = NA, FALSE)
Vtask_diff_PCminusTV_CIform    <- format_ci( Vtask_diff_PCminusTV, digits, width = NA, FALSE)
Vtask_diff_SMminusTV_CIform    <- format_ci( Vtask_diff_SMminusTV, digits, width = NA, FALSE)

cat("\n1. How do the three techniques perform in terms of speed in value retrieval task?")
cat("\n2. VA: Time of Value task in PC : " ,Vtask_mean_PC_CIform)
cat("\n2. VA: Time of Value task in SM : " ,Vtask_mean_SM_CIform)
cat("\n2. VA: Time of Value task in TV : " ,Vtask_mean_TV_CIform)
cat("\n2. VA: Value Task Time Difference PC/SM: ",Vtask_diff_PCminusSM_CIform)
cat("\n2. VA: Value Task Time Difference PC/TV: ",Vtask_diff_PCminusTV_CIform)
cat("\n2. VA: Value Task Time Difference SM/TV: ",Vtask_diff_PCminusTV_CIform)
